@@ -6,11 +6,8 @@ from flexget import plugin
 from flexget.event import event
 from flexget.utils.template import RenderError
 
-__version__ = 0.1
-
 log = logging.getLogger("sms_ru")
 
-client_headers = {"User-Agent": "FlexGet sms_ru plugin/%s" % str(__version__)}
 sms_send_url = "http://sms.ru/sms/send"
 sms_token_url = "http://sms.ru/auth/get_token"
 
@@ -51,7 +48,7 @@ class OutputSMSru(object):
         password = config["password"]
 
         # Backend provides temporary token
-        token_response = task.requests.get(sms_token_url, headers=client_headers, raise_status=False)
+        token_response = task.requests.get(sms_token_url, raise_status=False)
 
         if token_response.status_code == 200:
             log.debug("Got auth token")
@@ -87,7 +84,7 @@ class OutputSMSru(object):
                 send_params.update({'test': 1})
 
             # Make the request
-            response = task.requests.get(sms_send_url, params=send_params, headers=client_headers, raise_status=False)
+            response = task.requests.get(sms_send_url, params=send_params, raise_status=False)
 
             # Get resul code from sms.ru backend returned in body
             result_text = response.text
